@@ -253,8 +253,13 @@ proc insertRootPath {path} {
 }
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-# Method to set new list of root directories
+# Method to get and set list of root directories
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+proc getRootPaths {} {
+  global config
+  return [split $config(roots) ";"]
+}
+
 proc setRootPaths {paths} {
   global config
   set config(roots) $paths
@@ -273,22 +278,37 @@ proc push { sock } {
   # Scan all root directories for the file
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
   set dontcache false
-	foreach {path} [split $config(roots) ";"] {
+  foreach {path} [split $config(roots) ";"] {
     # a. Create a potential pathname
 		set mypath [ URLtoString "$path$data(url)"]
     regsub -all "\\.UP\\./" $mypath "../" mypath
 
-    # b. If pathname is a directory, add the default filename.
+    # b. If pathname is a directory, scan for default filename.
     if {[file isdirectory $mypath]} { 
       append mypath "/"
-      regsub {(//$)} $mypath "/" mypath 
-      append mypath $config(default) 
+      regsub {(//$)} $mypath "/" pathT
+      set mypath ""
+
+      # Scan for filename matching the default filename pattern
+      set pattern $config(default)
+      foreach {pathnameT} [glob -nocomplain -type f -directory $pathT *] {
+   	if {[file exists $pathnameT]} {
+	  set filenameT [file tail $pathnameT]
+          if {[regexp -nocase $pattern $filenameT dummy]} then {
+            set mypath $pathnameT
+            break
+          }
+	}
+      }
     }
 
     # c. If pathname refers to an existing file, we are done.
-   	if {[file exists $mypath]} {
-			break
+    if {[file exists $mypath]} {
+      ## puts "Found page file: $mypath\n"
+      break
     }
+
+    set mypath ""
   }
 
   # Ignore all ../
@@ -516,7 +536,7 @@ proc fmtdate {clicks} {
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 proc URLtoString {data} {
   regsub -all {([][$\\])} $data {\\\1}
-  regsub -all {%([0-9a-fA-F][0-9a-fA-F])} $data  {[format %c 0x\1]} data
+  regsub -all {%([0-9a-fA-F][0-9a-fA-F])} $data {[format %c 0x\1]} data
   return [subst $data]
 }
 
@@ -530,6 +550,11 @@ proc bgerror {msg} {
 
 ###############################################################################
 # HISTORY:
+# 2013-03-31
+# o Now push() uses $config(default) as a filename pattern, which makes
+#   it more flexible, e.g. default="^index[.](html|.*)$"
+# 2011-09-21
+# o Added getRootPaths() which returns a Tcl array.
 # 2009-09-16
 # o Updated HTTP header from 'HTTP/1.x [...]' to 'HTTP/1.1 [...]'.  Thanks
 #   Ryan Bressler (Institute for Systems Biology, Seattle) for this.
